Contributors
############

Thank you to all of the developers, programmers, and researchers who
contributed to the creation of MAICoS.

We also thank the `Institute for Computational Physics`_ (University of
Stuttgart), group members of `Roland Netz`_ at Freie Universität Berlin,
and the Stuttgart Center for Simulation Science and the German Research
Council (DFG) for funding through the Cluster of Excellence `EXC 2075`_
"Data-integrated Simulation Science".

History
-------

MAICoS was first developed in `Roland Netz`_'s group at the Freie University of
Berlin by `Alexander Schlaich`_ and `Philip Loche`_, and is now mostly developed
and maintained at the `Institute for Physics of functional Materials`_ (Hamburg University of Technology).

.. _Roland Netz: https://www.physik.fu-berlin.de/en/einrichtungen/ag/ag-netz/index.html
.. _Philip Loche: https://people.epfl.ch/philip.loche
.. _Alexander Schlaich:  https://tuhh.de/ipfm/people/schlaich
.. _Institute for Computational Physics: https://www.icp.uni-stuttgart.de/
.. _EXC 2075: https://www.simtech.uni-stuttgart.de/exc/
.. _Institute for Physics of functional Materials: https://www.tuhh.de/ipfm/

.. include:: ../../AUTHORS.rst
